@@ -3,7 +3,7 @@ import importlib
 
 pytom = toml.load("pyproject.toml")
 package_name = pytom["project"]["name"]
-author_name = " - ".join(pytom["project"]["authors"])
+author_name = " - ".join(pytom["project"]["authors"][0]["name"])
 
 doc_dir_name = "docs"
 doc_notebooks_dir = "notebooks"
